@@ -98,7 +98,6 @@ OC.L10N.register(
     "Path is already shared with this card" : "הנתיב כבר משותף עם הכרטיס הזה",
     "Invalid date, date format must be YYYY-MM-DD" : "תאריך שגוי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck הוא כלי ארגון בסגנון kanban המכוון לתכנון אישי ולארגון פרויקטים עבור צוותים המשולבים ב- Nextcloud.\n\n\n- 📥 הוסף את המשימות שלך לכרטיסים וסדר אותן\n- 📄 רשמו הערות נוספות ב-markdown\n- 🔖הקצה תוויות לארגון טוב עוד יותר\n- 👥 שתף עם הצוות שלך, חברים, או משפחה\n- 📎 צרף קבצים והטמע אותם בתיאור ה-markdown שלך\n- 💬 שוחח עם הצוות שלך באמצעות הערות\n- ⚡ עקוב אחר שינויים בזרם הפעילות\n- 🚀 ארגנו את הפרויקט שלכם",
     "Card details" : "פרטי הכרטיס",
     "Add board" : "הוספת לוח",
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
@@ -194,6 +193,8 @@ OC.L10N.register(
     "Set a due date" : "הגדרת תאריך יעד",
     "Remove due date" : "הסרת מועד התפוגה",
     "Select Date" : "בחירת תאריך",
+    "Today" : "היום",
+    "Tomorrow" : "מחר",
     "Save" : "שמור",
     "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
     "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
@@ -245,8 +246,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "למחוק את הלוח {title}? פעולה זו תמחק את כל הנתונים של הלוח הזה.",
     "Delete the board?" : "למחוק את הלוח הזה?",
     "Loading filtered view" : "טוען תצוגה מסוננת",
-    "Today" : "היום",
-    "Tomorrow" : "מחר",
     "This week" : "השבוע",
     "No due" : "אין תאריך יעד",
     "No upcoming cards" : "אין כרטיסים עתידיים",
@@ -259,6 +258,7 @@ OC.L10N.register(
     "Error creating the share" : "שגיאה ביצירת השיתוף",
     "Share with a Deck card" : "שיתוף עם כרטיס חפיסה",
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
-    "Share" : "שיתוף"
+    "Share" : "שיתוף",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck הוא כלי ארגון בסגנון kanban המכוון לתכנון אישי ולארגון פרויקטים עבור צוותים המשולבים ב- Nextcloud.\n\n\n- 📥 הוסף את המשימות שלך לכרטיסים וסדר אותן\n- 📄 רשמו הערות נוספות ב-markdown\n- 🔖הקצה תוויות לארגון טוב עוד יותר\n- 👥 שתף עם הצוות שלך, חברים, או משפחה\n- 📎 צרף קבצים והטמע אותם בתיאור ה-markdown שלך\n- 💬 שוחח עם הצוות שלך באמצעות הערות\n- ⚡ עקוב אחר שינויים בזרם הפעילות\n- 🚀 ארגנו את הפרויקט שלכם"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
