@@ -100,7 +100,6 @@ OC.L10N.register(
     "Path is already shared with this card" : "パスは既にこのカードで共有されています",
     "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
     "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
     "Card details" : "カード詳細",
     "Add board" : "ボードを追加",
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
@@ -181,6 +180,7 @@ OC.L10N.register(
     "Share from Files" : "ファイルから共有",
     "Add this attachment" : "この添付ファイルを追加",
     "Show in Files" : "ファイルに表示",
+    "Download" : "ダウンロード",
     "Delete Attachment" : "添付ファイルを削除",
     "Restore Attachment" : "添付ファイルを復元",
     "File to share" : "共有するファイル",
@@ -201,10 +201,15 @@ OC.L10N.register(
     "Set a due date" : "期限を設定",
     "Remove due date" : "期限を削除",
     "Select Date" : "日付を選択",
+    "Today" : "今日",
+    "Tomorrow" : "明日",
+    "Next week" : "来週",
+    "Next month" : "来月",
     "Save" : "保存",
     "The comment cannot be empty." : "コメントを空にすることはできません。",
     "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
     "In reply to" : "返信",
+    "Cancel reply" : "返信をキャンセル",
     "Reply" : "返信",
     "Update" : "更新",
     "Description" : "説明",
@@ -252,8 +257,6 @@ OC.L10N.register(
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "このボード{title}を削除してもよろしいですか？この操作はこのボードのデータすべてを削除します。",
     "Delete the board?" : "ボードを削除しますか？",
     "Loading filtered view" : "フィルタされたビューを読み込み中",
-    "Today" : "今日",
-    "Tomorrow" : "明日",
     "This week" : "今週",
     "No due" : "日付なし",
     "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
@@ -270,6 +273,7 @@ OC.L10N.register(
     "Error creating the share" : "共有の作成中にエラーが発生しました",
     "Share with a Deck card" : "デッキのカードで共有する",
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
-    "Share" : "共有"
+    "Share" : "共有",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する"
 },
 "nplurals=1; plural=0;");
