@@ -101,9 +101,16 @@ OC.L10N.register(
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
     "Search by board title" : "Ieškoti pagal lentos pavadinimą",
     "Select board" : "Pasirinkti lentą",
+    "Create a new card" : "Sukurti naują kortelę",
     "Select a board" : "Pasirinkite lentą",
     "Select a list" : "Pasirinkite sąrašą",
+    "Card title" : "Kortelės pavadinimas",
     "Cancel" : "Atsisakyti",
+    "Creating the new card …" : "Kuriama nauja kortelė…",
+    "Card \"{card}\" was added to \"{board}\"" : "Kortelė „{card}“ buvo pridėta į lentą „{board}“",
+    "Open card" : "Atverti kortelę",
+    "Close" : "Užverti",
+    "Create card" : "Sukurti kortelę",
     "Select a card" : "Pasirinkti kortelę",
     "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
     "Link to card" : "Susieti su kortele",
@@ -113,6 +120,7 @@ OC.L10N.register(
     "Overwrite file" : "Perrašyti failą",
     "Keep existing file" : "Palikti esamą failą",
     "This board is read only" : "Ši lenta yra tik skaitymui",
+    "Drop your files to upload" : "Tempkite failus, norėdami juos išsiųsti",
     "Add card" : "Pridėti kortelę",
     "Archived cards" : "Archyvuotos kortelės",
     "Add list" : "Pridėti sąrašą",
@@ -143,6 +151,7 @@ OC.L10N.register(
     "Undo" : "Atšaukti",
     "Deleted cards" : "Ištrintos kortelės",
     "Share board with a user, group or circle …" : "Bendrinti lentą su naudotoju, grupe ar ratu…",
+    "Searching for users, groups and circles …" : "Ieškoma naudotojų, grupių ir ratų…",
     "No participants found" : "Nerasta jokių dalyvių",
     "Board owner" : "Lentos savininkas",
     "(Group)" : "(Grupė)",
@@ -151,6 +160,7 @@ OC.L10N.register(
     "Can share" : "Can share",
     "Can manage" : "Gali tvarkyti",
     "Delete" : "Ištrinti",
+    "Failed to create share with {displayName}" : "Nepavyko sukurti viešinio su {displayName}",
     "Add a new list" : "Pridėti naują sąrašą",
     "Archive all cards" : "Archyvuoti visas korteles",
     "Delete list" : "Ištrinti sąrašą",
@@ -163,9 +173,15 @@ OC.L10N.register(
     "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
     "Board name" : "Lentos pavadinimas",
     "Members" : "Nariai",
+    "Upload new files" : "Išsiųsti naujus failus",
+    "Share from Files" : "Bendrinti iš failų",
     "Add this attachment" : "Pridėti šį priedą",
+    "Show in Files" : "Rodyti failuose",
+    "Download" : "Atsisiųsti",
+    "Remove attachment" : "Šalinti priedą",
     "Delete Attachment" : "Ištrinti priedą",
     "Restore Attachment" : "Atkurti priedą",
+    "File to share" : "Failas, kurį bendrinti",
     "Invalid path selected" : "Pasirinktas neteisingas kelias",
     "Open in sidebar view" : "Atverti šoninės juostos rodinyje",
     "Open in bigger view" : "Atverti didesniame rodinyje",
@@ -173,7 +189,9 @@ OC.L10N.register(
     "Comments" : "Komentarai",
     "Modified" : "Pakeistas",
     "Created" : "Sukurta",
+    "The title cannot be empty." : "Pavadinimas negali būti tuščias.",
     "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
+    "Failed to load comments" : "Nepavyko įkelti komentarų",
     "Assign a tag to this card…" : "Priskirti šiai kortelei žymę…",
     "Assign to users" : "Priskirti naudotojams",
     "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
@@ -199,17 +217,20 @@ OC.L10N.register(
     "Write a description …" : "Parašykite aprašą…",
     "Choose attachment" : "Pasirinkite priedą",
     "(group)" : "(grupė)",
+    "{count} comments, {unread} unread" : "Komentarų: {count}, neskaityta: {unread}",
     "Assign to me" : "Priskirti sau",
     "Move card" : "Perkelti kortelę",
     "Unarchive card" : "Išarchyvuoti kortelę",
     "Archive card" : "Archyvuoti kortelę",
     "Delete card" : "Ištrinti kortelę",
     "Move card to another board" : "Perkelti kortelę į kitą lentą",
+    "List is empty" : "Sąrašas tuščias",
     "Card deleted" : "Kortelė ištrinta",
     "seconds ago" : "prieš keletą sekundžių",
     "All boards" : "Visos lentos",
     "Archived boards" : "Archyvuotos lentos",
     "Shared with you" : "Bendrinama su jumis",
+    "Use bigger card view" : "Naudoti didesnį kortelių rodinį",
     "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
     "Board details" : "Išsamiau apie lentą",
     "Edit board" : "Taisyti lentą",
@@ -230,11 +251,15 @@ OC.L10N.register(
     "Delete the board?" : "Ištrinti lentą?",
     "This week" : "Šią savaitę",
     "No due" : "Be galutinio termino",
+    "No results found" : "Nerasta jokių rezultatų",
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
+    "Create a card" : "Sukurti kortelę",
     "Something went wrong" : "Kažkas nutiko",
     "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
     "Error creating the share" : "Klaida kuriant viešinį",
-    "Share" : "Bendrinti"
+    "Share" : "Bendrinti",
+    "Creating the new card…" : "Kuriama nauja kortelė…",
+    "(circle)" : "(ratas)"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
