@@ -92,7 +92,7 @@ OC.L10N.register(
     "Example Task 2" : "示例任務 2",
     "Example Task 1" : "示例任務 1",
     "The file was uploaded" : "檔案已上傳",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳檔案的大小已超過 php.ini 中 upload_max_filesize 設置的值",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
     "The file was only partially uploaded" : "檔案僅部分上傳",
     "No file was uploaded" : "沒有檔案被上傳",
@@ -100,11 +100,12 @@ OC.L10N.register(
     "Could not write file to disk" : "寫入硬碟失敗",
     "A PHP extension stopped the file upload" : "某個 PHP 擴充功能終止檔案的上傳",
     "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
+    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "此評論超過%s個字符。\n作為附件添加到名稱為 %s 的卡片上。\n可於此 URL  存取：%s。",
     "Card not found" : "未找到卡片",
     "Path is already shared with this card" : "已和這張卡片分享了路徑",
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
     "Personal planning and team project organization" : "個人規劃和團隊項目組織",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 增加您的任務到card和把它們整理好\n- 📄 寫下額外的筆記在markdown\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊，朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 markdown 描述\n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的項目井井有條",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 添加您的任務到 card 及將之整理好\n- 📄 用 Markdown 寫下額外的註釋分享分享分享\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊、朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 Markdown 描述中 \n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的專案井井有條",
     "Card details" : "卡片詳情",
     "Add board" : "添加面板",
     "Select the board to link to a project" : "選擇要連結到一個項目的面板",
@@ -188,6 +189,7 @@ OC.L10N.register(
     "Pending share" : "等待分享",
     "Add this attachment" : "添加此附件",
     "Show in Files" : "顯示在檔案中",
+    "Download" : "下載",
     "Remove attachment" : "移除附件",
     "Delete Attachment" : "刪除附件",
     "Restore Attachment" : "恢復附件",
@@ -239,6 +241,7 @@ OC.L10N.register(
     "Archive card" : "封存卡片",
     "Delete card" : "刪除卡片",
     "Move card to another board" : "將卡片移到其他面板",
+    "List is empty" : "列表是空的",
     "Card deleted" : "卡片被刪除",
     "seconds ago" : "幾秒前",
     "All boards" : "全部面板",
@@ -283,6 +286,10 @@ OC.L10N.register(
     "Error creating the share" : "創建分享出錯",
     "Share with a Deck card" : "用一張 Deck 卡片進行分享 ",
     "Share {file} with a Deck card" : "用一張 Deck 卡片分享 {file}",
-    "Share" : "分享"
+    "Share" : "分享",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 增加您的任務到card和把它們整理好\n- 📄 寫下額外的筆記在markdown\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊，朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 markdown 描述\n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的項目井井有條",
+    "Creating the new card…" : "正在建立新卡片...",
+    "\"{card}\" was added to \"{board}\"" : "\"{card}\" 已添加到 \"{board}\"",
+    "(circle)" : "（社交圈子）"
 },
 "nplurals=1; plural=0;");
