@@ -50,6 +50,7 @@ use OCA\Deck\Db\BoardMapper;
 use OCA\Deck\Db\LabelMapper;
 use OCP\IUserManager;
 use OCA\Deck\BadRequestException;
+use OCP\IURLGenerator;
 
 class BoardService {
 	private $boardMapper;
@@ -68,8 +69,8 @@ class BoardService {
 	private $activityManager;
 	private $eventDispatcher;
 	private $changeHelper;
-
 	private $boardsCache = null;
+	private $urlGenerator;
 
 
 	public function __construct(
@@ -87,6 +88,7 @@ class BoardService {
 		ActivityManager $activityManager,
 		IEventDispatcher $eventDispatcher,
 		ChangeHelper $changeHelper,
+		IURLGenerator $urlGenerator,
 		$userId
 	) {
 		$this->boardMapper = $boardMapper;
@@ -104,6 +106,7 @@ class BoardService {
 		$this->eventDispatcher = $eventDispatcher;
 		$this->changeHelper = $changeHelper;
 		$this->userId = $userId;
+		$this->urlGenerator = $urlGenerator;
 	}
 
 	/**
@@ -697,4 +700,8 @@ class BoardService {
 		}
 		$board->setUsers(array_values($boardUsers));
 	}
+
+	public function getBoardUrl($endpoint) {
+		return $this->urlGenerator->linkToRouteAbsolute('deck.page.index') . '#' . $endpoint;
+	}
 }
