@@ -35,6 +35,7 @@ use OCA\Deck\Db\ChangeHelper;
 use OCA\Deck\Db\LabelMapper;
 use OCA\Deck\Db\Stack;
 use OCA\Deck\Db\StackMapper;
+use OCA\Deck\NoPermissionException;
 use OCA\Deck\StatusException;
 
 class StackService {
@@ -48,7 +49,6 @@ class StackService {
 	private $assignedUsersMapper;
 	private $attachmentService;
 	private $activityManager;
-	private $symfonyAdapter;
 	private $changeHelper;
 
 	public function __construct(
@@ -110,6 +110,7 @@ class StackService {
 			throw new BadRequestException('stack id must be a number');
 		}
 
+		$this->permissionService->checkPermission($this->stackMapper, $stackId, Acl::PERMISSION_READ);
 		$stack = $this->stackMapper->find($stackId);
 		$cards = $this->cardMapper->findAll($stackId);
 		foreach ($cards as $cardIndex => $card) {
@@ -142,7 +143,12 @@ class StackService {
 	}
 
 	public function findCalendarEntries($boardId) {
-		$this->permissionService->checkPermission(null, $boardId, Acl::PERMISSION_READ);
+		try {
+			$this->permissionService->checkPermission(null, $boardId, Acl::PERMISSION_READ);
+		} catch (NoPermissionException $e) {
+			\OC::$server->getLogger()->error('Unable to check permission for a previously obtained board ' . $boardId, ['exception' => $e]);
+			return [];
+		}
 		return $this->stackMapper->findAll($boardId);
 	}
 
@@ -284,8 +290,8 @@ class StackService {
 			throw new BadRequestException('order must be a number');
 		}
 
-		$this->permissionService->checkPermission($this->stackMapper, $id, Acl::PERMISSION_MANAGE);
-		if ($this->boardService->isArchived($this->stackMapper, $id)) {
+		$this->permissionService->checkPermission($this->stackMapper, $boardId, Acl::PERMISSION_MANAGE);
+		if ($this->boardService->isArchived($this->stackMapper, $boardId)) {
 			throw new StatusException('Operation not allowed. This board is archived.');
 		}
 		$stack = $this->stackMapper->find($id);
